@@ -1,4 +1,4 @@
-/* $Id: bomb.h,v 1.5 2005/04/10 00:22:16 stpohle Exp $
+/* $Id: bomb.h,v 1.6 2006/02/06 21:18:01 stpohle Exp $
  * bomb include file
  */
 
@@ -37,8 +37,9 @@ struct {
         unsigned char state;    // state of the bomb BS_*
         unsigned char mode;     // mode of the bomb BM_*
         int ex_nr;              // explosion number
+	_point source;		// start of a kicked bomb
         _point dest;            // destination to move the bomb to
-        float speed;            // bomb moving speed
+        float speed;            // bomb moving speed or kicked bomb 0.0=start 1.0=end
 } typedef _bomb;
 
 
