@@ -1,4 +1,4 @@
-/* $Id: sysfunc.h,v 1.6 2004/01/07 23:04:31 patty21 Exp $ */
+/* $Id: sysfunc.h,v 1.8 2006/08/08 19:49:39 stpohle Exp $ */
 /* include some system near functions */
 
 #ifndef _SYSFUNC_H_
@@ -26,6 +26,7 @@ struct __direntry {
 } typedef _direntry;
 
 extern void s_delay (int ms);
+extern int s_fetchevent (SDL_Event *event);
 extern int s_random (int maxnr);
 extern char *s_gethomedir ();
 extern int s_countbits (int nbomb, int nr);
@@ -53,6 +54,14 @@ extern _direntry *s_dirfilter (_direntry *dirstart, signed char dirflags);
 	#endif
 #endif
 
+/*
+ * somehow this works.. 
+ * something missing in the stdarg.h file?
+ */
+#ifndef HAVE_VSNPRINTF
+	#define vsnprintf _vsnprintf
+#endif
+
 extern inline void s_calctimesync ();
 extern void rect_clipping (SDL_Rect *src, SDL_Rect *dest, SDL_Rect *window, SDL_Rect *csrc, SDL_Rect *cdest);
 extern void charlist_fillarraypointer (_charlist *list, int c);
