@@ -1,4 +1,4 @@
-/* $Id: bomb.c,v 1.63 2005/04/09 18:22:40 stpohle Exp $ */
+/* $Id: bomb.c,v 1.64 2005/07/06 13:11:55 stpohle Exp $ */
 /* everything what have to do with the bombs */
 
 #include "bomberclone.h"
@@ -19,8 +19,6 @@ draw_bomb (_bomb * bomb)
       y1,
       y2;
 
-	if (bman.dedicated)
-		return;
 	
     if (x < 0 || y < 0 || x >= map.size.x || y >= map.size.y) {
         d_printf ("FATAL: Draw Bomb out of range [%f,%f]\n", x, y);
