@@ -1,4 +1,4 @@
-/* $Id: menu.c,v 1.50 2005/03/27 01:31:50 stpohle Exp $
+/* $Id: menu.c,v 1.53 2006/02/06 21:18:01 stpohle Exp $
  * Menuhandling */
 
 #include "basic.h"
@@ -538,9 +538,9 @@ menu_loop (_menu * menu)
                 reorder = 0;
         }
 
-        eventstate = SDL_PollEvent (&event);
+        eventstate = s_fetchevent (&event);
 
-        done = menu_event_loop (menu, &event, eventstate);
+	done = menu_event_loop (menu, &event, eventstate);
 
         s_calctimesync ();
     }
@@ -629,7 +629,7 @@ menu_displaymessage (char *title, char *fmt, ...)
     memset (text, 0, sizeof (text));
     memset (out, 0, sizeof (out));
     va_start (args, fmt);
-    vsprintf (text, fmt, args);
+    vsnprintf (text, 512, fmt, args);
     va_end (args);
 
     menu_formattext (text, out, lines, &linenr, &maxlinelen, MENU_MESSAGES_MAXLINELEN,
@@ -722,7 +722,7 @@ menu_displaytext (char *title, char *fmt, ...)
     memset (text, 0, sizeof (text));
     memset (out, 0, sizeof (out));
     va_start (args, fmt);
-    vsprintf (text, fmt, args);
+    vsnprintf (text, 512, fmt, args);
     va_end (args);
 
     menu_formattext (text, out, lines, &linenr, &maxlinelen, MENU_MESSAGES_MAXLINELEN,
