@@ -1,4 +1,4 @@
-/* $Id: network.c,v 1.74 2005/04/10 00:22:17 stpohle Exp $ */
+/* $Id: network.c,v 1.77 2006/08/13 21:26:50 stpohle Exp $ */
 /*
 	network routines.
 */
@@ -133,9 +133,8 @@ network_init ()
     }
 
     // we have got our socket.. so now allocate the memory for the resend_cache
-    resend_cache.data = (char *) malloc (PKG_RESENDCACHE_SIZE);
-    resend_cache.fill = 0;
-
+	rscache_init ();
+	
     return 0;
 };
 
@@ -180,12 +179,6 @@ network_shutdown ()
 
     udp_close (bman.sock);
 
-    if (resend_cache.data != NULL)
-        free (resend_cache.data);
-
-    resend_cache.data = NULL;
-    resend_cache.fill = -1;
-
     bman.p_nr = -1;
     bman.sock = -1;
 #ifdef _WIN32
@@ -250,7 +243,7 @@ network_loop ()
                       &addr.sAddr);
 
     while (inlen > 0) {
-        do_pkg (packet, &addr);
+        do_pkg (packet, &addr, inlen);
 
         //  printf ("Network : inlen (%d) typ (%d) Size (%d)\n", inlen, packet->typ, pkglen);
         inlen = udp_get (bman.sock, data, MAX_UDPDATA, &addr.sAddr, bman.net_ai_family);
@@ -477,14 +470,12 @@ net_transmit_gamedata ()
     Uint8 *keys;
     Uint32 downtimestamp = 0;
 
-    if (!bman.dedicated) {
-        draw_logo ();
+    draw_logo ();
 
-        if (GT_MP_PTPM)
-            font_draw (100, 0, "Waiting for the Clients", 1, 0);
-        else
-            font_draw (100, 0, "Downloading Data", 1, 0);
-    }
+    if (GT_MP_PTPM)
+        font_draw (100, 0, "Waiting for the Clients", 1, 0);
+    else
+        font_draw (100, 0, "Downloading Data", 1, 0);
 
     /* 
        prepare everything for the loop 
@@ -505,10 +496,8 @@ net_transmit_gamedata ()
     else
         net_istep = 3;
 
-    if (!bman.dedicated) {
-        draw_netupdatestate (1);
-        SDL_Flip (gfx.screen);
-    }
+    draw_netupdatestate (1);
+    SDL_Flip (gfx.screen);
 
     downtimestamp = timestamp;
     while (!done && (bman.state == GS_update || (GT_MP_PTPS && net_istep != 0))) {
@@ -617,40 +606,37 @@ net_transmit_gamedata ()
         }
 
         /* do the grafik work */
-        if (!bman.dedicated) {
-            draw_netupdatestate (0);
+        draw_netupdatestate (0);
 
-            if (SDL_PollEvent (&event) != 0)
-                switch (event.type) {
-                case (SDL_QUIT):
-                    bman.state = GS_quit;
-                    bman.p_nr = -1;
-                    done = 1;
-                }
-
-            keys = SDL_GetKeyState (NULL);
-
-            if (keys[SDLK_ESCAPE] && event.type == SDL_KEYDOWN) {
-                done = 1;
+        if (s_fetchevent (&event) != 0)
+            switch (event.type) {
+            case (SDL_QUIT):
+                bman.state = GS_quit;
                 bman.p_nr = -1;
-                keypressed = 1;
-                bman.state = GS_startup;
+                done = 1;
             }
 
-            if (event.type == SDL_KEYUP)
-                keypressed = 0;
-        }
+        keys = SDL_GetKeyState (NULL);
 
-        timestamp = SDL_GetTicks (); // needed for time sync.
-        SDL_Delay (1);          // we don't need here anything better
-
-        /* player is only watching so just go after we have got everything
-           go to show the field */
-        if (GT_MP_PTPS && bman.state == GS_update && net_istep == 0
-            && players[bman.p_nr].gfx_nr == -1) {
+        if (keys[SDLK_ESCAPE] && event.type == SDL_KEYDOWN) {
             done = 1;
-            bman.state = GS_running;
+            bman.p_nr = -1;
+            keypressed = 1;
+            bman.state = GS_startup;
         }
+
+        if (event.type == SDL_KEYUP)
+            keypressed = 0;
+    }
+
+    timestamp = SDL_GetTicks (); // needed for time sync.
+    SDL_Delay (1);              // we don't need here anything better
+
+    /* player is only watching so just go after we have got everything
+       go to show the field */
+    if (GT_MP_PTPS && bman.state == GS_update && net_istep == 0 && players[bman.p_nr].gfx_nr == -1) {
+        done = 1;
+        bman.state = GS_running;
     }
 };
 
