@@ -1,4 +1,4 @@
-/* $Id: player.c,v 1.101 2005/04/11 22:21:14 stpohle Exp $
+/* $Id: player.c,v 1.103 2006/08/15 15:58:39 stpohle Exp $
  * player.c - everything what have to do with the player */
 
 #include <SDL.h>
@@ -17,9 +17,6 @@ draw_player (_player * player)
     SDL_Rect src,
       dest;
     int i;
-
-	if (bman.dedicated)
-		return;
 	
     if ((int)player->pos.x < 0 || (int)player->pos.x >= map.size.x ||
         (int)player->pos.y < 0 || (int)player->pos.y >= map.size.y) {
@@ -301,7 +298,9 @@ stepmove_player (int pl_nr)
     _pointf _pos,	// position inside the field
 	  d;			// distance to move
 	float speed = 0.0f;
-	
+
+	d.x = d.y = 0.0f;
+
     if (p->m == 1) {
         _pos.x = CUTINT(p->pos.x);
         _pos.y = CUTINT(p->pos.y);
@@ -582,8 +581,6 @@ draw_players ()
 {
     int p;
 	
-	if (bman.dedicated) return;
-	
     for (p = 0; p < MAX_PLAYERS; p++) {
         if (PS_IS_playing (players[p].state) && players[p].tunnelto <= 0)
             draw_player (&players[p]);
