@@ -1,4 +1,4 @@
-/* $Id: playermenu.c,v 1.16 2004/12/26 04:19:20 stpohle Exp $ 
+/* $Id: playermenu.c,v 1.18 2005/08/07 17:46:21 stpohle Exp $ 
  */
 
 #include "bomberclone.h"
@@ -28,7 +28,9 @@ static void playermenu_selgfx_drawplayer (int selgfx, _menu *menu) {
 	static int changed = 0;
 	SDL_Rect rect, srcrect;
 	int i;
-
+	int i_start;
+	int i_end;
+	
 	/*
 	 * delete old state, to force an update of all playergfx
 	 */
@@ -50,26 +52,36 @@ static void playermenu_selgfx_drawplayer (int selgfx, _menu *menu) {
 		rect.h = 4 * GFX_IMGSIZE;
 		menu_draw_background (menu, &rect);
 		
-		for (i = 0; i < gfx.player_gfx_count; i++) {
-			srcrect.h = rect.h = gfx.players[i].menu_image->h;
-			srcrect.w = rect.w = gfx.players[i].menu_image->w;
+		/* calculate the first element on the screen */
+		if (gfx.player_gfx_count < 12 || selgfx < 4) i_start = 0;
+		else {
+			i_start = (((selgfx / 4)-1) * 4);
+			if (i_start < 0) i_start = 0;
+		}
+		
+		if ((i_end = i_start + 12) > gfx.player_gfx_count)
+			i_end = gfx.player_gfx_count;
+		
+		for (i = 0; i < i_end - i_start; i++) {
+			srcrect.h = rect.h = gfx.players[i + i_start].menu_image->h;
+			srcrect.w = rect.w = gfx.players[i + i_start].menu_image->w;
 			rect.x = (2 * GFX_MENUPLAYERIMGSIZE_X) * (i % 4) + ((menu->oldscreenpos.w - 2 * menuimages[0]->w) - (8 * GFX_MENUPLAYERIMGSIZE_X)) / 2;
 			rect.y = (GFX_MENUPLAYERIMGSIZE_X * 2) * (i / 4) + PLAYERMENU_GFXSEL_Y;
 			srcrect.x = 0;
 			srcrect.y = 0;
 			rect.x += menu->oldscreenpos.x + menuimages[0]->w;
 			rect.y += menu->oldscreenpos.y + menuimages[0]->h;
-	        gfx_blit (gfx.players[i].menu_image, &srcrect, gfx.screen, &rect, 10002);
+	        gfx_blit (gfx.players[i + i_start].menu_image, &srcrect, gfx.screen, &rect, 10002);
 			
 			/* draw the select border */
-			if (i == selgfx) {
+			if ((i + i_start) == selgfx) {
 				srcrect.x = 0;
 				srcrect.y = 0;
 				srcrect.h = rect.h = GFX_IMGSIZE;
 				srcrect.w = rect.w = GFX_IMGSIZE;
 				rect.x = GFX_IMGSIZE * (i % 4) + ((menu->oldscreenpos.w - 2 * menuimages[0]->w) -(4 * GFX_IMGSIZE)) / 2;
 				rect.y = GFX_IMGSIZE * (i / 4) + PLAYERMENU_GFXSEL_Y;
-				rect.x += (gfx.players[i].menu_image->w - gfx.menuselect.image->w) / 2; // center the playergfx
+				rect.x += (gfx.players[i + i_start].menu_image->w - gfx.menuselect.image->w) / 2; // center the playergfx
 				rect.x += menu->oldscreenpos.x + menuimages[0]->w;
 				rect.y += menu->oldscreenpos.y + menuimages[0]->h;
 	        	gfx_blit (gfx.menuselect.image, &srcrect, gfx.screen, &rect, 10001);
@@ -98,7 +110,10 @@ int playermenu_selgfx (int pl_nr) {
 	playermenu_selgfx_drawplayer (-1, NULL);
 	player_set_gfx (&players[pl_nr], -1);
 	
-	menu = menu_new ("Player Selection", 400, 270);
+	if (gfx.player_gfx_count > 8)
+		menu = menu_new ("Player Selection", 400, 330);
+	else 
+		menu = menu_new ("Player Selection", 400, 270);
 	menu_create_text (menu, "playergfxsel", -1, 50, 40, 5, COLOR_yellow, "%s, please select your Player and press ENTER/RETURN or press ESCAPE for no player (that means you will only watch the next game).", players[pl_nr].name);
 
     menu->looprunning = 1;
@@ -113,7 +128,7 @@ int playermenu_selgfx (int pl_nr) {
                 ogc_loop ();
         }
 		
-        eventstate = SDL_PollEvent (&event);
+        eventstate = s_fetchevent (&event);
 
         if (eventstate) {
             switch (event.type) {
@@ -285,7 +300,7 @@ void playermenu () {
 		detail_Addr->changed = 1;
 		detail_Flags->changed = 1;
 		
-		eventstate = SDL_PollEvent (&event);
+		eventstate = s_fetchevent (&event);
 		if (bman.sock != -1)
 			network_loop ();
 
