@@ -1,4 +1,4 @@
-/* $Id: single.c,v 1.84 2005/02/14 20:09:19 stpohle Exp $ */
+/* $Id: single.c,v 1.85 2005/08/07 17:46:21 stpohle Exp $ */
 /* single player */
 
 #include "basic.h"
@@ -744,7 +744,7 @@ single_menu ()
 	
 	do {
 		gfx_blitdraw ();
-		eventstate = SDL_PollEvent (&event);
+		eventstate = s_fetchevent (&event);
 
 		done = menu_event_loop (menu, &event, eventstate);
 
