@@ -1,4 +1,4 @@
-/* $Id: special.c,v 1.36 2004/10/18 18:27:20 stpohle Exp $ */
+/* $Id: special.c,v 1.37 2004/12/26 23:18:40 stpohle Exp $ */
 /* special.c - procedues to control the specials */
 
 #include "bomberclone.h"
@@ -100,6 +100,8 @@ special_liquidmoved (int p_nr)
 
     dx = dir_change[p->d].x;
     dy = dir_change[p->d].y;
+	x += dx;
+	y += dy;
 	
     // check that player is beside a bomb
     if (!map.bfield[x][y])
